@@ -12,7 +12,7 @@ use strict;
 use warnings;
 
 package App::RouterColorizer;
-$App::RouterColorizer::VERSION = '1.242480';
+$App::RouterColorizer::VERSION = '1.242880';
 use Moose;
 
 use feature 'signatures';
@@ -341,6 +341,9 @@ s/^ ( $INTSHORT \s+ $STP_TYPES\s+ $STP_BAD  \s+ [0-9]+ \s+ [0-9]+\.[0-9]+ \s+ P2
     $line =~ s/^ (Connection: \s Active \s .*) $/$self->_colorize($1, $GREEN)/exx;
     $line =~ s/^ (Connection: \s .*          ) $/$self->_colorize($1, $RED)/exx;
 
+    # Error in authentication
+    $line =~ s/^(Error in authentication)$/$self->_colorize($1, $RED)/e;
+
     return $line;
 }
 
@@ -831,7 +834,7 @@ App::RouterColorizer - Colorize router CLI output
 
 =head1 VERSION
 
-version 1.242480
+version 1.242880
 
 =head1 DESCRIPTION
 
